@@ -6,9 +6,19 @@ from pathlib import Path
 from textwrap import indent
 from typing import Iterator, Tuple
 
-from .model.base import ConfigurationEntry, Connection, INDENTATION, \
-    Mediation, Mediator, Model, ModelMesh, ModelType, ModelVerbosity, \
-    RemapMethod, SequenceEntry
+from .model.base import (
+    ConfigurationEntry,
+    Connection,
+    INDENTATION,
+    Mediation,
+    Mediator,
+    Model,
+    ModelMesh,
+    ModelType,
+    ModelVerbosity,
+    RemapMethod,
+    SequenceEntry,
+)
 from .utilities import get_logger
 
 LOGGER = get_logger('configuration')
@@ -48,8 +58,9 @@ class Earth(ConfigurationEntry):
     def __setitem__(self, model_type: ModelType, model: Model):
         assert model_type == model.model_type
         if self.__models[model_type] is not None:
-            LOGGER.warning(f'overwriting existing "{model_type.name}" model: '
-                           f'{repr(self[model_type])}')
+            LOGGER.warning(
+                f'overwriting existing "{model_type.name}" model: ' f'{repr(self[model_type])}'
+            )
         self.__models[model_type] = model
 
     def __contains__(self, model_type: ModelType):
@@ -61,25 +72,27 @@ class Earth(ConfigurationEntry):
 
     def __str__(self) -> str:
         attributes = [
-            f'{attribute} = ' \
-            f'{value if not isinstance(value, Enum) else value.value}'
+            f'{attribute} = {value if not isinstance(value, Enum) else value.value}'
             for attribute, value in self.attributes.items()
         ]
 
-        return '\n'.join([
-            f'{self.entry_type}_component_list: '
-            f'{" ".join(model_type.value for model_type, model in self.models.items() if model is not None)}',
-            f'{self.entry_type}_attributes::',
-            indent('\n'.join(attributes), INDENTATION),
-            '::'
-        ])
+        return '\n'.join(
+            [
+                f'{self.entry_type}_component_list: '
+                f'{" ".join(model_type.value for model_type, model in self.models.items() if model is not None)}',
+                f'{self.entry_type}_attributes::',
+                indent('\n'.join(attributes), INDENTATION),
+                '::',
+            ]
+        )
 
     def __repr__(self) -> str:
-        kwargs = [f'{model_type.name}={repr(model)}'
-                  for model_type, model in self.models.items()] + \
-                 [f'{key}={value}'
-                  for key, value in self.attributes.items()]
-        return f'{self.__class__.__name__}({self.attributes["Verbosity"]}, {", ".join(kwargs)})'
+        kwargs = [
+                     f'{model_type.name}={repr(model)}' for model_type, model in self.models.items()
+                 ] + [f'{key}={value}' for key, value in self.attributes.items()]
+        return (
+            f'{self.__class__.__name__}({self.attributes["Verbosity"]}, {", ".join(kwargs)})'
+        )
 
 
 class RunSequence(ConfigurationEntry, SequenceEntry):
@@ -87,8 +100,7 @@ class RunSequence(ConfigurationEntry, SequenceEntry):
 
     def __init__(self, interval: timedelta, verbose: bool = False, **kwargs):
         self.interval = interval
-        self.verbosity = ModelVerbosity.MAXIMUM \
-            if verbose else ModelVerbosity.MINIMUM
+        self.verbosity = ModelVerbosity.MAXIMUM if verbose else ModelVerbosity.MINIMUM
 
         self.__models = {}
         for key, value in kwargs.items():
@@ -100,8 +112,9 @@ class RunSequence(ConfigurationEntry, SequenceEntry):
                 for model_type, model in value:
                     self.__models[model_type] = model
 
-        self.__sequence = [model for model in self.models
-                           if model.model_type != ModelType.MEDIATOR]
+        self.__sequence = [
+            model for model in self.models if model.model_type != ModelType.MEDIATOR
+        ]
         self.__link_models()
 
     def append(self, entry: SequenceEntry):
@@ -132,30 +145,29 @@ class RunSequence(ConfigurationEntry, SequenceEntry):
                 if isinstance(entry, Model):
                     model_type = entry.model_type
                     if model_type in self.__models:
-                        raise TypeError(f'duplicate model type '
-                                        f'"{model_type.name}" in given sequence')
+                        raise TypeError(
+                            f'duplicate model type ' f'"{model_type.name}" in given sequence'
+                        )
                     self.__models[model_type] = entry
             self.__link_models()
             self.__sequence = sequence
 
-    def connect(self, source: ModelType, target: ModelType,
-                method: RemapMethod = None, **kwargs):
+    def connect(
+            self, source: ModelType, target: ModelType, method: RemapMethod = None, **kwargs
+    ):
         if method is None:
             method = RemapMethod.REDISTRIBUTE
-        if ModelType.MEDIATOR in [source, target] and \
-                self.mediator is None:
+        if ModelType.MEDIATOR in [source, target] and self.mediator is None:
             self.mediator = Mediator('implicit', **kwargs)
         if source not in self.__models:
             raise KeyError(f'no {source.name} model in sequence')
         if target not in self.__models:
             raise KeyError(f'no {target.name} model in sequence')
-        self.append(Connection(self[source], self[target],
-                               method))
+        self.append(Connection(self[source], self[target], method))
 
     @property
     def connections(self) -> [Connection]:
-        return [entry for entry in self.sequence
-                if isinstance(entry, Connection)]
+        return [entry for entry in self.sequence if isinstance(entry, Connection)]
 
     @property
     def mediator(self) -> Mediator:
@@ -168,9 +180,15 @@ class RunSequence(ConfigurationEntry, SequenceEntry):
     def mediator(self, mediator: Mediator):
         self[ModelType.MEDIATOR] = mediator
 
-    def mediate(self, source: ModelType = None, target: ModelType = None,
-                functions: [str] = None, method: RemapMethod = None,
-                processors: int = None, **attributes):
+    def mediate(
+            self,
+            source: ModelType = None,
+            target: ModelType = None,
+            functions: [str] = None,
+            method: RemapMethod = None,
+            processors: int = None,
+            **attributes,
+    ):
 
         if self.mediator is None:
             self.mediator = Mediator('implicit', processors, **attributes)
@@ -186,18 +204,15 @@ class RunSequence(ConfigurationEntry, SequenceEntry):
         if target is not None:
             target = self[target]
 
-        self.append(Mediation(source, self.mediator, target, functions,
-                              method))
+        self.append(Mediation(source, self.mediator, target, functions, method))
 
     @property
     def mediations(self) -> [Mediation]:
-        return [entry for entry in self.sequence
-                if isinstance(entry, Mediation)]
+        return [entry for entry in self.sequence if isinstance(entry, Mediation)]
 
     @property
     def earth(self) -> Earth:
-        return Earth(self.verbosity, **{model.model_type.name: model
-                                        for model in self.models})
+        return Earth(self.verbosity, **{model.model_type.name: model for model in self.models})
 
     @property
     def processors(self) -> int:
@@ -221,8 +236,9 @@ class RunSequence(ConfigurationEntry, SequenceEntry):
         assert model_type == model.model_type
         if model_type in self.__models:
             existing_model = self.__models[model_type]
-            LOGGER.warning(f'overwriting {model_type.name} model '
-                           f'"{existing_model}" with "{model}"')
+            LOGGER.warning(
+                f'overwriting {model_type.name} model ' f'"{existing_model}" with "{model}"'
+            )
             self.__sequence.remove(self.__sequence.index(existing_model))
         self.__models[model_type] = model
         self.__link_models()
@@ -232,9 +248,11 @@ class RunSequence(ConfigurationEntry, SequenceEntry):
 
     @property
     def models(self) -> [Model]:
-        models = [model for model_type, model in self.__models.items()
-                  if model_type in self and
-                  model_type is not ModelType.MEDIATOR]
+        models = [
+            model
+            for model_type, model in self.__models.items()
+            if model_type in self and model_type is not ModelType.MEDIATOR
+        ]
         if self.mediator is not None:
             models.insert(0, self.mediator)
         return models
@@ -254,24 +272,20 @@ class RunSequence(ConfigurationEntry, SequenceEntry):
         return str(self)
 
     def __str__(self) -> str:
-        block = '\n'.join([
-            f'@{self.interval / timedelta(seconds=1):.0f}',
-            indent('\n'.join(entry.sequence_entry
-                             for entry in self.__sequence),
-                   INDENTATION),
-            '@'
-        ])
-        return '\n'.join([
-            f'runSeq::',
-            indent(block, INDENTATION),
-            '::'
-        ])
+        block = '\n'.join(
+            [
+                f'@{self.interval / timedelta(seconds=1):.0f}',
+                indent(
+                    '\n'.join(entry.sequence_entry for entry in self.__sequence), INDENTATION
+                ),
+                '@',
+            ]
+        )
+        return '\n'.join([f'runSeq::', indent(block, INDENTATION), '::'])
 
     def __repr__(self) -> str:
-        models = [f'{model.model_type.name.lower()}={repr(model)}'
-                  for model in self.models]
-        return f'{self.__class__.__name__}({repr(self.interval)}, ' \
-               f'{", ".join(models)})'
+        models = [f'{model.model_type.name.lower()}={repr(model)}' for model in self.models]
+        return f'{self.__class__.__name__}({repr(self.interval)}, {", ".join(models)})'
 
 
 class ConfigurationFile(ABC):
@@ -303,8 +317,9 @@ class NEMSConfigurationFile(ConfigurationFile):
         filename = directory / self.name
 
         if filename.exists():
-            LOGGER.warning(f'{"overwriting" if overwrite else "skipping"} '
-                           f'existing file "{filename}"')
+            LOGGER.warning(
+                f'{"overwriting" if overwrite else "skipping"} ' f'existing file "{filename}"'
+            )
         if not filename.exists() or overwrite:
             LOGGER.debug(f'writing NEMS configuration to "{filename}"')
             with open(filename, 'w') as output_file:
@@ -319,13 +334,12 @@ class NEMSConfigurationFile(ConfigurationFile):
             yield entry
 
     def __str__(self) -> str:
-        return '#############################################\n' \
-               '####  NEMS Run-Time Configuration File  #####\n' \
-               '#############################################\n' \
-               '\n' + \
-               '\n'.join(f'# {entry.entry_type} #\n'
-                         f'{entry}\n'
-                         for entry in self)
+        return (
+                '#############################################\n'
+                '####  NEMS Run-Time Configuration File  #####\n'
+                '#############################################\n'
+                '\n' + '\n'.join(f'# {entry.entry_type} #\n' f'{entry}\n' for entry in self)
+        )
 
 
 class MeshFile(ConfigurationFile):
@@ -336,8 +350,9 @@ class MeshFile(ConfigurationFile):
         filename = directory / self.name
 
         if filename.exists():
-            LOGGER.warning(f'{"overwriting" if overwrite else "skipping"} '
-                           f'existing file "{filename}"')
+            LOGGER.warning(
+                f'{"overwriting" if overwrite else "skipping"} ' f'existing file "{filename}"'
+            )
         if not filename.exists() or overwrite:
             LOGGER.debug(f'writing mesh filenames to "{filename}"')
             with open(filename, 'w') as output_file:
@@ -345,23 +360,20 @@ class MeshFile(ConfigurationFile):
 
     @property
     def entries(self) -> [ModelMesh]:
-        return [entry for entry in self.sequence
-                if isinstance(entry, ModelMesh)]
+        return [entry for entry in self.sequence if isinstance(entry, ModelMesh)]
 
     def __iter__(self) -> Iterator[ConfigurationEntry]:
         for entry in self.entries:
             yield entry
 
     def __str__(self) -> str:
-        return '\n'.join([ModelMesh.__str__(model_mesh)
-                          for model_mesh in self]) + '\n'
+        return '\n'.join([ModelMesh.__str__(model_mesh) for model_mesh in self]) + '\n'
 
 
 class ModelConfigurationFile(ConfigurationFile):
     name = 'model_configure'
 
-    def __init__(self, start_time: datetime, duration: timedelta,
-                 sequence: RunSequence):
+    def __init__(self, start_time: datetime, duration: timedelta, sequence: RunSequence):
         self.start_time = start_time
         self.duration = duration
         super().__init__(sequence)
@@ -371,8 +383,9 @@ class ModelConfigurationFile(ConfigurationFile):
         filename = directory / self.name
 
         if filename.exists():
-            LOGGER.warning(f'{"overwriting" if overwrite else "skipping"} '
-                           f'existing file "{filename}"')
+            LOGGER.warning(
+                f'{"overwriting" if overwrite else "skipping"} ' f'existing file "{filename}"'
+            )
         if not filename.exists() or overwrite:
             LOGGER.debug(f'writing model configuration to "{filename}"')
             with open(filename, 'w') as output_file:
@@ -388,132 +401,131 @@ class ModelConfigurationFile(ConfigurationFile):
 
     def __str__(self) -> str:
         duration_hours = round(self.duration / timedelta(hours=1))
-        return '\n'.join([
-            'core: gfs',
-            'print_esmf:     .true.',
-            '',
-            'nhours_dfini=0',
-            '',
-            '#nam_atm +++++++++++++++++++++++++++',
-            'nlunit:                  35',
-            'deltim:                  900.0',
-            'fhrot:                   0',
-            'namelist:                atm_namelist',
-            'total_member:            1',
-            'grib_input:              0',
-            f'PE_MEMBER01:             {self.sequence.processors}',
-            'PE_MEMBER02',
-            'PE_MEMBER03',
-            'PE_MEMBER04',
-            'PE_MEMBER05',
-            'PE_MEMBER06',
-            'PE_MEMBER07',
-            'PE_MEMBER08',
-            'PE_MEMBER09',
-            'PE_MEMBER10',
-            'PE_MEMBER11',
-            'PE_MEMBER12',
-            'PE_MEMBER13',
-            'PE_MEMBER14',
-            'PE_MEMBER15',
-            'PE_MEMBER16',
-            'PE_MEMBER17',
-            'PE_MEMBER18',
-            'PE_MEMBER19:',
-            'PE_MEMBER20:',
-            'PE_MEMBER21:',
-            '',
-            '# For stochastic perturbed runs -  added by Dhou and Wyang',
-            '--------------------------------------------------------',
-            '#  ENS_SPS, logical control for application of stochastic '
-            'perturbation scheme',
-            '#  HH_START, start hour of forecast, and modified '
-            'ADVANCECOUNT_SETUP',
-            '#  HH_INCREASE and HH_FINAL are fcst hour increment and end '
-            'hour of forecast',
-            '#  ADVANCECOUNT_SETUP is an integer indicating the number of '
-            'time steps between integration_start and the time when model '
-            'state is saved for the _ini of the GEFS_Coupling, currently is '
-            '0h.',
-            '',
-            'HH_INCREASE:             600',
-            'HH_FINAL:                600',
-            'HH_START:                0',
-            'ADVANCECOUNT_SETUP:      0',
-            '',
-            'ENS_SPS:                 .false.',
-            'HOUTASPS:                10000',
-            '',
-            '#ESMF_State_Namelist +++++++++++++++',
-            '',
-            'RUN_CONTINUE:            .false.',
-            '',
-            '#',
-            'dt_int:                  900',
-            'dt_num:                  0',
-            'dt_den:                  1',
-            f'start_year:              {self.start_time.year}',
-            f'start_month:             {self.start_time.month}',
-            f'start_day:               {self.start_time.day}',
-            f'start_hour:              {self.start_time.hour}',
-            f'start_minute:            {self.start_time.minute}',
-            f'start_second:            {self.start_time.second}',
-            f'nhours_fcst:             {duration_hours:.0f}',
-            'restart:                 .false.',
-            f'nhours_fcst1:            {duration_hours:.0f}',
-            'im:                      192',
-            'jm:                      94',
-            'global:                  .true.',
-            'nhours_dfini:            0',
-            'adiabatic:               .false.',
-            'lsoil:                   4',
-            'passive_tracer:          .true.',
-            'dfilevs:                 64',
-            'ldfiflto:                .true.',
-            'num_tracers:             3',
-            'ldfi_grd:                .false.',
-            'lwrtgrdcmp:              .false.',
-            'nemsio_in:               .false.',
-            '',
-            '',
-            '#jwstart added quilt',
-            '###############################',
-            '#### Specify the I/O tasks ####',
-            '###############################',
-            '',
-            '',
-            'quilting:                .false.   #For asynchronous '
-            'quilting/history writes',
-            'read_groups:             0',
-            'read_tasks_per_group:    0',
-            'write_groups:            1',
-            'write_tasks_per_group:   3',
-            '',
-            'num_file:                3                   #',
-            'filename_base:           \'SIG.F\' \'SFC.F\' \'FLX.F\'',
-            'file_io_form:            \'bin4\' \'bin4\' \'bin4\'',
-            'file_io:                 \'DEFERRED\' \'DEFERRED\' \'DEFERRED\' '
-            '\'DEFERRED\'  #',
-            'write_dopost:            .false.          # True--> run do on '
-            'quilt',
-            'post_gribversion:        grib1      # True--> grib version for '
-            'post output files',
-            'gocart_aer2post:         .false.',
-            'write_nemsioflag:        .TRUE.       # True--> Write nemsio '
-            'run history files',
-            'nfhout:                  3',
-            'nfhout_hf:               1',
-            'nfhmax_hf:               0',
-            'nsout:                   0',
-            '',
-            'io_recl:                 100',
-            'io_position:             \' \'',
-            'io_action:               \'WRITE\'',
-            'io_delim:                \' \'',
-            'io_pad:                  \' \'',
-            '',
-            '#jwend'
-        ])
+        return '\n'.join(
+            [
+                'core: gfs',
+                'print_esmf:     .true.',
+                '',
+                'nhours_dfini=0',
+                '',
+                '#nam_atm +++++++++++++++++++++++++++',
+                'nlunit:                  35',
+                'deltim:                  900.0',
+                'fhrot:                   0',
+                'namelist:                atm_namelist',
+                'total_member:            1',
+                'grib_input:              0',
+                f'PE_MEMBER01:             {self.sequence.processors}',
+                'PE_MEMBER02',
+                'PE_MEMBER03',
+                'PE_MEMBER04',
+                'PE_MEMBER05',
+                'PE_MEMBER06',
+                'PE_MEMBER07',
+                'PE_MEMBER08',
+                'PE_MEMBER09',
+                'PE_MEMBER10',
+                'PE_MEMBER11',
+                'PE_MEMBER12',
+                'PE_MEMBER13',
+                'PE_MEMBER14',
+                'PE_MEMBER15',
+                'PE_MEMBER16',
+                'PE_MEMBER17',
+                'PE_MEMBER18',
+                'PE_MEMBER19:',
+                'PE_MEMBER20:',
+                'PE_MEMBER21:',
+                '',
+                '# For stochastic perturbed runs -  added by Dhou and Wyang',
+                '--------------------------------------------------------',
+                '#  ENS_SPS, logical control for application of stochastic '
+                'perturbation scheme',
+                '#  HH_START, start hour of forecast, and modified ' 'ADVANCECOUNT_SETUP',
+                '#  HH_INCREASE and HH_FINAL are fcst hour increment and end '
+                'hour of forecast',
+                '#  ADVANCECOUNT_SETUP is an integer indicating the number of '
+                'time steps between integration_start and the time when model '
+                'state is saved for the _ini of the GEFS_Coupling, currently is '
+                '0h.',
+                '',
+                'HH_INCREASE:             600',
+                'HH_FINAL:                600',
+                'HH_START:                0',
+                'ADVANCECOUNT_SETUP:      0',
+                '',
+                'ENS_SPS:                 .false.',
+                'HOUTASPS:                10000',
+                '',
+                '#ESMF_State_Namelist +++++++++++++++',
+                '',
+                'RUN_CONTINUE:            .false.',
+                '',
+                '#',
+                'dt_int:                  900',
+                'dt_num:                  0',
+                'dt_den:                  1',
+                f'start_year:              {self.start_time.year}',
+                f'start_month:             {self.start_time.month}',
+                f'start_day:               {self.start_time.day}',
+                f'start_hour:              {self.start_time.hour}',
+                f'start_minute:            {self.start_time.minute}',
+                f'start_second:            {self.start_time.second}',
+                f'nhours_fcst:             {duration_hours:.0f}',
+                'restart:                 .false.',
+                f'nhours_fcst1:            {duration_hours:.0f}',
+                'im:                      192',
+                'jm:                      94',
+                'global:                  .true.',
+                'nhours_dfini:            0',
+                'adiabatic:               .false.',
+                'lsoil:                   4',
+                'passive_tracer:          .true.',
+                'dfilevs:                 64',
+                'ldfiflto:                .true.',
+                'num_tracers:             3',
+                'ldfi_grd:                .false.',
+                'lwrtgrdcmp:              .false.',
+                'nemsio_in:               .false.',
+                '',
+                '',
+                '#jwstart added quilt',
+                '###############################',
+                '#### Specify the I/O tasks ####',
+                '###############################',
+                '',
+                '',
+                'quilting:                .false.   #For asynchronous '
+                'quilting/history writes',
+                'read_groups:             0',
+                'read_tasks_per_group:    0',
+                'write_groups:            1',
+                'write_tasks_per_group:   3',
+                '',
+                'num_file:                3                   #',
+                "filename_base:           'SIG.F' 'SFC.F' 'FLX.F'",
+                "file_io_form:            'bin4' 'bin4' 'bin4'",
+                "file_io:                 'DEFERRED' 'DEFERRED' 'DEFERRED' " "'DEFERRED'  #",
+                'write_dopost:            .false.          # True--> run do on ' 'quilt',
+                'post_gribversion:        grib1      # True--> grib version for '
+                'post output files',
+                'gocart_aer2post:         .false.',
+                'write_nemsioflag:        .TRUE.       # True--> Write nemsio '
+                'run history files',
+                'nfhout:                  3',
+                'nfhout_hf:               1',
+                'nfhmax_hf:               0',
+                'nsout:                   0',
+                '',
+                'io_recl:                 100',
+                "io_position:             ' '",
+                "io_action:               'WRITE'",
+                "io_delim:                ' '",
+                "io_pad:                  ' '",
+                '',
+                '#jwend',
+            ]
+        )
 
 
 def ensure_directory(directory: PathLike) -> Path:
